@@ -1,4 +1,4 @@
-#include "cs_kroneckerI.h"
+#include "MCMCglmm.h"
 
 cs *cs_kroneckerI(const cs *A, int nI){
 
